@@ -250,7 +250,10 @@ class GMail():
         print(f'Found {len(messages)} messages')
         return messages
     
-    def fetchEmails(self, searchTerm, userId='me', subject=None, label=None, hasAttachment=False, maxResults=None, pageToken=None, includeSpamTrash=False, getAttachments=False):
+    def fetchEmails(self, searchTerm, userId='me', subject=None, label=None, hasAttachment=False, maxResults=None, pageToken=None, includeSpamTrash=False, getAttachments=False, directory='../downloads'):
+        '''
+        directory: relative path to destination folder
+        '''
 
         emailIds = self.fetchEmailIds(searchTerm, userId=userId, subject=subject, label=label, hasAttachment=hasAttachment, maxResults=maxResults, pageToken=pageToken, includeSpamTrash=includeSpamTrash)
 
@@ -290,7 +293,9 @@ class GMail():
                         attachmentId = part['body']['attachmentId']
                         attachment = self.service.users().messages().attachments().get(userId='me', messageId=emailId['id'], id=attachmentId).execute()
                         file_data = base64.urlsafe_b64decode(attachment['data'].encode('UTF-8'))
-                        filename = f"downloads/{emailId['id']}_{part['filename']}"
+                        dirname = os.path.dirname(__file__)
+                        filename = f"{directory}/{emailId['id']}_{part['filename']}"
+                        filename = os.path.join(dirname, filename)
                         with open(filename, 'wb') as f:
                             f.write(file_data)
                         message['attachments'].extend([filename])
